@@ -2681,6 +2681,10 @@ N_("Drag and drop sensor rows to change the displayed order.\n"),
 "\n",
 N_("Temperature offset values must be in centigrade units.\n"),
 "\n",
+N_("If you use Pango markup for any custom labels, do not use double quotes.\n"),
+N_("For example, to set a colored CPU label, use single quotes:\n"),
+N_("    <span foreground='cyan'>CPU</span>\n"),
+"\n",
 N_("Substitution variables may be used in alert commands.\n"),
 N_("\t$s    current sensor value.\n"),
 N_("\t$l    sensor label.\n"),
